/*
 * Copyright (C) 2001 LAAS/CNRS
 *
 * David Bonnafous - Anthony Mallet - Wed Jul 18 2001
 *
 * $Log: p3dStruct.h,v $
 * Revision 1.8  2007/10/23 13:13:21  sjoyeux
 * misc fixes
 *
 *   * don't set the status to FAILED when we're blocked but still trying
 *   * don't resetRef when we reached the current waypoint, unless it is
 *     the last one. If there is still waypoints to execute, go to the
 *     next and try planning again
 *
 * Revision 1.7  2007/10/19 08:11:59  sjoyeux
 * bump the maximum number of waypoints manageable by P3D, to be on par with nav's trajectories
 *
 * Revision 1.6  2007/09/10 12:32:21  sjoyeux
 * cleanup of the permanent codel, export the solution path instead of only one single arc
 *
 *   The following changes are included:
 *     * the CurrentArc poster is no more, hail to the Path poster. CurrentArc
 *       was only including the first arc of the solution while Path includes
 *       all the arcs
 *     * do not change u-turn direction once we chose one. This fixes bad
 *       behaviours related to asynchronicity between pom, rflex and p3d.
 *       The low u-turn watermark should not be too low, though, or the robot
 *       will keep spinning around
 *     * when we are blocked, we should not remove the current waypoint
 *     * reinitialize the u-turning flag when a new path is found: since we
 *       changed the current goal, we should not u-turn unless necessary
 *     * some fixes to mixed indentation (there was 2, 3 and 4-spaces indentation)
 *     * nicer debugging output
 *
 * Revision 1.5  2007/06/28 17:08:00  tpeynot
 *
 * Add p3d Configuration Monitor (comparison between predicted and observed configuration/attitude of the robot)
 * This is an import of the old genom version.
 *
 * Main news:
 * - Specific task named MonitorTask (lower priority than ExecTask)
 * - Request ConfigMonitor to start the monitor (with possibility to log monitoring results in a file)
 * - Monitoring data exported in a poster (named Monitoring)
 *
 * Revision 1.4  2007/06/19 15:50:07  sjoyeux
 * Better handling of the P3D error conditions
 *   * handle the planning state in the Track request (it was only done in Goto before)
 *   * nbfailed is not used, remove
 *   * move nbblocked into the P3DStatus structure
 *
 * Revision 1.3  2007/04/16 13:42:40  sjoyeux
 * Cleanup and dtm compatibility
 *   * remove references to lloco
 *   * use GENPOS_TRAJ_POINTS to get our trajectory
 *   * dem -> dtm name change
 *
 * Revision 1.2  2007/01/29 12:24:47  sjoyeux
 * Take position poster name at initialization (instead of hardcoding pomPos)
 *
 * Revision 1.1.1.1  2006/10/17 18:13:19  sjoyeux
 * Importing OpenGenom version of P3D
 *   * disabled the display task for now (I don't want to manage
 *     the dependency on GDHE, and calife-p3d has display removed
 *     as well)
 *   * compiles with -DATRV. Needs lloco otherwise, so I expect
 *     it to fail badly
 *
 *
 *
 * Revision 1.6.2.11  2005/04/26 14:01:41  tpeynot
 * Add Request PlaceRobotOnMap to test placement on one particular position
 *
 * Revision 1.6.2.10  2005/04/18 12:46:23  tpeynot
 * parameters and struct fields for ATRV-like robots defined
 * #if defined(ATRV) || (ATRV_JUNIOR)
 *
 * Revision 1.6.2.9  2005/04/13 20:32:21  tpeynot
 * Add ground clearance info and parameters/variables
 *
 * Revision 1.6.2.8  2005/04/07 20:50:27  tpeynot
 * Add parameters for Dala body collision test to be made in calife p3d
 *
 * Revision 1.6.2.7  2005/03/31 15:06:28  tpeynot
 * Remove some comments in Display Requests (most of the things are now definitely done using functions in
 * lama/calife/src/p3d/display.c)
 * Add Request to display robot's configurations predicted by p3dPlan
 *
 * Revision 1.6.2.6  2005/03/24 22:50:03  tpeynot
 * Add Display functionalities and Fuctions to read Dem maps
 *
 * Revision 1.6.2.5  2005/03/17 10:35:44  tpeynot
 * Gdhe Display functions: display cylinders on WayPoints locations and an Arc from the robot position to illustrate the (v,w)_ref computed by p3d planner
 *
 * Revision 1.6.2.4  2005/03/09 10:30:42  tpeynot
 * Merging...
 *
 *
 * Revision 1.6.2.3  2005/03/09 10:23:39  tpeynot
 * Add Parameters for Requests for a GDHE Display (Preparation)
 *
 * Revision 1.6.2.2  2005/03/08 16:16:19  tpeynot
 * Add specific parameters value for dala (ATRV)
 *
 * Revision 1.6.2.1  2004/09/13 09:05:47  ginfante
 * PIMisation
 *
 * Revision 1.6  2003/09/23 13:36:47  slemai
 *
 *
 * Ajout d'une requete GoTo dans p3d, avec renvoi d'un bilan quand le but est atteint .( messages d'echec : failed / blocked)
 *
 * Revision 1.5  2002/10/09 15:49:59  mallet
 * Remplace le theta-demi-tour par deux (high,low) "water mark".
 * (modifier les paramètres de la requête correspondante dans les scripts).
 *
 * Ajoute un 'vMin' à côté du 'vMax' pour adapter la vitesse du robal au
 * cout du chemin, avec la formule v = vMin + (vMax - vMin)/cout, cout étant
 * dans [1;+inf[
 *
 * Revision 1.4  2002/06/17 18:14:41  mallet
 * Ajoute un theta au dela duquel p3d fait un demi-tour.
 * Exporte la distance au but dans le poster des way-points
 *
 * Revision 1.3  2001/09/29 15:30:14  mallet
 * maj
 *
 * Revision 1.2  2001/07/24 10:07:55  mallet
 * sirs
 *
 */
#ifndef P3DSTRUCT_H
#define P3DSTRUCT_H

/***********************************************************************/
/* Some general constants */
#define	P3D_MAX_STRLEN	64
#define P3D_MAX_LENGTH_NAME 1024

#define P3D_DEFAULT_DTM_POSTER_NAME "dtmP3dPoster"


/***********************************************************************/

typedef struct P3D_INIT {
    char pomPoster[256];
} P3D_INIT;

/* Robot geometry ---------------------------------------------------- */

typedef struct P3DLamaGeom {
   float len0;		/* big cylinder length */
   float len1;		/* cone length */
   float len2;		/* axle length */

   float rad0;		/* big cylinder */
   float rad1;		/* axle */

   float arm0;		/* front arm */
   float arm1;		/* back arm */

   float scale;		/* bitmap scale */
   double rollStep;	/* roll precision (deg) */

   double vMin;		/* m/s */
   double vMax;		/* m/s */
   double accel;	/* m.s-2 */
   double decel;	/* m.s-2 */
   double wMax;		/* rad/s */

  /* params de bas de caisse */
  double bodyLength;  /* Length and width of ATRV's under body */
  double bodyWidth;
  double zBody;      /* dz between Robot's center and under body */
  /* dz entre centre du robot et bas de caisse */
  double groundClear;  /* ground clearance (garde au sol) */

#if defined(ATRV) || defined(ATRV_JUNIOR) /*----- DALA or GROMIT -----*/
  /* Definir ici des valeurs par defaut adaptees au cas Dala */
#define P3D_DEFAULT_WHEEL_LEN0	(.155)  /* Largeur de la roue */
#define P3D_DEFAULT_WHEEL_LEN1	(.032) /* largeur du cylindre entre roue et caisse */
#define P3D_DEFAULT_WHEEL_LEN2	(.2275) /* Largeur du "cylindre" demi caisse */

#define P3D_DEFAULT_WHEEL_RAD0	(.195) /* Rayon de la roue */
#define P3D_DEFAULT_WHEEL_RAD1	(.09)   /* Rayon du "cylindre" demi caisse -> a verifier*/

#define P3D_DEFAULT_WHEEL_ARM0	(.2225)  /* Longueur entre centre robot et essieu avant */
#define P3D_DEFAULT_WHEEL_ARM1	(.2225)  /* Longueur entre centre robot et essieu arriere */

#define P3D_DEFAULT_WHEEL_SCALE	(.04)
#define P3D_DEFAULT_WHEEL_ROLLSTEP (1.)

  /*-- Body bottom (fond de caisse) default params values --*/
#define P3D_DEFAULT_BODY_LENGTH (0.84)
#define P3D_DEFAULT_BODY_WIDTH  (0.455)
#define P3D_DEFAULT_GROUND_CLEARANCE (0.115)  /* Garde au sol */
#define P3D_DEFAULT_BODY_Z      (-P3D_DEFAULT_WHEEL_RAD0+P3D_DEFAULT_GROUND_CLEARANCE)
#elif defined(RMP400)

  /* Definir ici des valeurs par defaut adaptees au cas Mana */
#define P3D_DEFAULT_WHEEL_LEN0	(.155)  /* Largeur de la roue */
#define P3D_DEFAULT_WHEEL_LEN1	(.305) /* largeur du cylindre entre roue et caisse */
#define P3D_DEFAULT_WHEEL_LEN2	(.0) /* Largeur du "cylindre" demi caisse */

#define P3D_DEFAULT_WHEEL_RAD0	(.51) /* Rayon de la roue */
#define P3D_DEFAULT_WHEEL_RAD1	(.09)   /* Rayon du "cylindre" demi caisse -> a verifier*/

#define P3D_DEFAULT_WHEEL_ARM0	(.27)  /* Longueur entre centre robot et essieu avant */
#define P3D_DEFAULT_WHEEL_ARM1	(.27)  /* Longueur entre centre robot et essieu arriere */

#define P3D_DEFAULT_WHEEL_SCALE	(.04)
#define P3D_DEFAULT_WHEEL_ROLLSTEP (1.)

  /*-- Body bottom (fond de caisse) default params values --*/
#define P3D_DEFAULT_BODY_LENGTH (0.95)
#define P3D_DEFAULT_BODY_WIDTH  (0.390)
#define P3D_DEFAULT_GROUND_CLEARANCE (0.115)  /* Garde au sol */
#define P3D_DEFAULT_BODY_Z      (-P3D_DEFAULT_WHEEL_RAD0+P3D_DEFAULT_GROUND_CLEARANCE)

#elif defined(RMP440)

  /* Definir ici des valeurs par defaut adaptees au cas Mana */
#define P3D_DEFAULT_WHEEL_LEN0	(.168)  /* Largeur de la roue */
#define P3D_DEFAULT_WHEEL_LEN1	(.337) /* largeur du cylindre entre roue et caisse */
#define P3D_DEFAULT_WHEEL_LEN2	(.0) /* Largeur du "cylindre" demi caisse */

#define P3D_DEFAULT_WHEEL_RAD0	(.53) /* Rayon de la roue */
#define P3D_DEFAULT_WHEEL_RAD1	(.09)   /* Rayon du "cylindre" demi caisse -> a verifier*/

#define P3D_DEFAULT_WHEEL_ARM0	(.285)  /* Longueur entre centre robot et essieu avant */
#define P3D_DEFAULT_WHEEL_ARM1	(.285)  /* Longueur entre centre robot et essieu arriere */

#define P3D_DEFAULT_WHEEL_SCALE	(.04)
#define P3D_DEFAULT_WHEEL_ROLLSTEP (1.)

  /*-- Body bottom (fond de caisse) default params values --*/
#define P3D_DEFAULT_BODY_LENGTH (0.95)
#define P3D_DEFAULT_BODY_WIDTH  (0.390)
#define P3D_DEFAULT_GROUND_CLEARANCE (0.115)  /* Garde au sol */
#define P3D_DEFAULT_BODY_Z      (-P3D_DEFAULT_WHEEL_RAD0+P3D_DEFAULT_GROUND_CLEARANCE)

#elif defined(IVMOB)

  /* Definir ici des valeurs par defaut adaptees au cas Mana */
#define P3D_DEFAULT_WHEEL_LEN0	(.168)  /* Largeur de la roue */
#define P3D_DEFAULT_WHEEL_LEN1	(.31) /* largeur du cylindre entre roue et caisse */
#define P3D_DEFAULT_WHEEL_LEN2	(.0) /* Largeur du "cylindre" demi caisse */

#define P3D_DEFAULT_WHEEL_RAD0	(.52) /* Rayon de la roue XXX isnt it diameter ? */
#define P3D_DEFAULT_WHEEL_RAD1	(.09)   /* Rayon du "cylindre" demi caisse -> a verifier*/

#define P3D_DEFAULT_WHEEL_ARM0	(.3)  /* Longueur entre centre robot et essieu avant */
#define P3D_DEFAULT_WHEEL_ARM1	(.3)  /* Longueur entre centre robot et essieu arriere */

#define P3D_DEFAULT_WHEEL_SCALE	(.04)
#define P3D_DEFAULT_WHEEL_ROLLSTEP (1.)

  /*-- Body bottom (fond de caisse) default params values --*/
#define P3D_DEFAULT_BODY_LENGTH (1)
#define P3D_DEFAULT_BODY_WIDTH  (0.42)
#define P3D_DEFAULT_GROUND_CLEARANCE (0.15)  /* Garde au sol */
#define P3D_DEFAULT_BODY_Z      (-P3D_DEFAULT_WHEEL_RAD0+P3D_DEFAULT_GROUND_CLEARANCE)


#else  /*----- Default values for LAMA -----*/
#define P3D_DEFAULT_WHEEL_LEN0	(.1)
#define P3D_DEFAULT_WHEEL_LEN1	(.45)
#define P3D_DEFAULT_WHEEL_LEN2	(.05)

#define P3D_DEFAULT_WHEEL_RAD0	(.225)
#define P3D_DEFAULT_WHEEL_RAD1	(.1)

#define P3D_DEFAULT_WHEEL_ARM0	(.7)
#define P3D_DEFAULT_WHEEL_ARM1	(.7)

#define P3D_DEFAULT_WHEEL_SCALE	(.04)
#define P3D_DEFAULT_WHEEL_ROLLSTEP (1.)

  /*-- Body Bottom default params values --*/
  /*-- Unused on LAMA => default values = 0.0 --*/
#define P3D_DEFAULT_BODY_LENGTH (0.0)
#define P3D_DEFAULT_BODY_WIDTH  (0.0)
#define P3D_DEFAULT_BODY_Z      (0.0)

#endif

#define P3D_DEFAULT_VMAX		(.1)
#define P3D_DEFAULT_VMIN		(.03)
#define P3D_DEFAULT_WMAX		(.03)
#define P3D_DEFAULT_ACCEL		(1)	/* Not so useful on atrv */
#define P3D_DEFAULT_DECEL		(1)

} P3DLamaGeom;


/* Robot limits ------------------------------------------------------ */

typedef struct P3DLamaLimits {
   double rollLimits[3];	/* of middle axle (deg) */
   double pitchLimits[3];	/* of middle axle (deg) */
   double alphaLimits[3];	/* front and back (deg) */
  /* Dala: relative roll angle between front and back axle */

   double betaLimits[3];	/* centered on M_PI (deg) */
  /* Dala: unused */

   double unkMax;	/* per wheel percentage */


#if defined(ATRV) || defined(ATRV_JUNIOR)
  /* Definir ici des valeurs par defaut adaptees au cas Dala */
#define P3D_DEFAULT_ROLLLIMIT0 (12.5)
#define P3D_DEFAULT_ROLLLIMIT1 (25.0)
#define P3D_DEFAULT_ROLLLIMIT2 (35.0)

#define P3D_DEFAULT_PITCHLIMIT0 (12.5)
#define P3D_DEFAULT_PITCHLIMIT1 (25.0)
#define P3D_DEFAULT_PITCHLIMIT2 (35.0)

#define P3D_DEFAULT_ALPHALIMIT0 (1.0)
#define P3D_DEFAULT_ALPHALIMIT1 (2.0)
#define P3D_DEFAULT_ALPHALIMIT2 (3.0)

#define P3D_DEFAULT_BETALIMIT0  (10.0)
#define P3D_DEFAULT_BETALIMIT1  (20.0)
#define P3D_DEFAULT_BETALIMIT2  (30.0)

#define P3D_DEFAULT_UNKMAX	(0.5)

#elif defined(RMP400) || defined(RMP440) || defined(IVMOB)

  /* Definir ici des valeurs par defaut adaptees au cas Mana */
#define P3D_DEFAULT_ROLLLIMIT0 (12.5)
#define P3D_DEFAULT_ROLLLIMIT1 (25.0)
#define P3D_DEFAULT_ROLLLIMIT2 (35.0)

#define P3D_DEFAULT_PITCHLIMIT0 (12.5)
#define P3D_DEFAULT_PITCHLIMIT1 (25.0)
#define P3D_DEFAULT_PITCHLIMIT2 (35.0)

#define P3D_DEFAULT_ALPHALIMIT0 (1.0)
#define P3D_DEFAULT_ALPHALIMIT1 (2.0)
#define P3D_DEFAULT_ALPHALIMIT2 (3.0)

#define P3D_DEFAULT_BETALIMIT0  (10.0)
#define P3D_DEFAULT_BETALIMIT1  (20.0)
#define P3D_DEFAULT_BETALIMIT2  (30.0)

#define P3D_DEFAULT_UNKMAX	(0.5)

#else  /* Default values for LAMA */

#define P3D_DEFAULT_ROLLLIMIT0 (15.0)
#define P3D_DEFAULT_ROLLLIMIT1 (30.0)
#define P3D_DEFAULT_ROLLLIMIT2 (45.0)

#define P3D_DEFAULT_PITCHLIMIT0 (15.0)
#define P3D_DEFAULT_PITCHLIMIT1 (30.0)
#define P3D_DEFAULT_PITCHLIMIT2 (45.0)

#define P3D_DEFAULT_ALPHALIMIT0 (5.0)
#define P3D_DEFAULT_ALPHALIMIT1 (10.0)
#define P3D_DEFAULT_ALPHALIMIT2 (15.0)

#define P3D_DEFAULT_BETALIMIT0  (10.0)
#define P3D_DEFAULT_BETALIMIT1  (20.0)
#define P3D_DEFAULT_BETALIMIT2  (30.0)

#define P3D_DEFAULT_UNKMAX	(0.5)
#endif

} P3DLamaLimits;

/* Arcs params ------------------------------------------------------- */

typedef struct P3DArcsParams {
   int nArcs;		/* total number of arcs */
   int nNodes;		/* total number of nodes by arcs */

   int depth;		/* arc nesting */

   float rMin;		/* min radius */

   float dMin;		/* min arc length */

   float goalToal;	/* goal tolerance (m) */

   float p3d_dMin;  /* Minimal size of arc for p3d algo */


#define P3D_DEFAULT_ARC_N		(20)
#define P3D_DEFAULT_ARC_DEPTH		(2)
#define P3D_DEFAULT_ARC_NNODES		(10)
#define P3D_DEFAULT_ARC_RMIN		(1.)
#define P3D_DEFAULT_ARC_DMIN		(0.5)
#define P3D_DEFAULT_ARC_GOALTOL		(0.5)
#define P3D_DEFAULT_P3D_ARC_DMIN	(2.0)

} P3DArcsParams;


/* Plan params ------------------------------------------------------- */

typedef struct P3DPlanParams {
   double period;	/* of p3dPlan() (% of trajectory) */


   double thetaUTurnHi;	/* max theta beyond which p3d makes a U-turn */
   double thetaUTurnLow;/* (high-water and low-water marks) */

#define P3D_DEFAULT_PLAN_PERIOD		(.1)
#define P3D_DEFAULT_THETAUTURNHI	(100)
#define P3D_DEFAULT_THETAUTURNLOW	(30)

} P3DPlanParams;


/* Save Lane map params --------------------------------------------------- */

typedef struct P3DSDIIo {
   char fileName[1024];		/* base name */

#define P3D_DEFAULT_FILE	"tinguely:/local/images/p3dmap"
} P3DSDIIo;


/* Save P3d map params --------------------------------------------------- */

typedef struct P3D_SAVEMAP_PARAMS {
   char fileName[P3D_MAX_LENGTH_NAME];		/* File Name */

#define P3D_MAP_DEFAULT_FILENAME	"/home/tpeynot/Images/p3dmap"
} P3D_SAVEMAP_PARAMS;




/* Way points -------------------------------------------------------- */

typedef struct P3DWayPoint {
   float x;			/* 2d coordinates */
   float y;
   GENPOS_MOTION_DIRECTION dir;
} P3DWayPoint;

#define P3D_MAX_WAYPOINTS	(1000)

typedef struct P3DWayPointList {
   int number;			/* number of wps */
   P3DWayPoint wps[P3D_MAX_WAYPOINTS];
} P3DWayPointList;


/* Poster: distance to goal ------------------------------------------ */

typedef struct P3DGoalDistance {
   double distance;
} P3DGoalDistance;

typedef enum P3D_STATUS_FLAG{
  P3D_MOVING,
  P3D_GOAL_REACHED,
  P3D_BLOCKED,
  P3D_FAILED,
  P3D_FAILED_POSTER
} P3D_STATUS_FLAG;

typedef struct P3DStatus {
  P3D_STATUS_FLAG status;
  int blocked_cycles;
} P3DStatus;

#define P3D_DEFAULT_GOAL_DIST_BOUND (0.6)



/***** Thierry *****************************************************/
/* Structure used to record the positions and configurations on the selected arc */

#define P3D_DEFAULT_MAX_NUMNODES (20)
/*-- This should be more than 20 --*/

typedef struct P3DRobotConfigGen {
   double q;		/* quality in [0;1], <0 indicates error */

   double x,y,z,theta;	/* position */
  /** Inutile car deja dnas Nodes ?? */

  double dzBodyGround;  /* min. height between robot body bottom and ground */

   double roll, pitch;	/* of middle axle */
   double alpha1, alpha2;/* front and back axle roll */
   double beta3;	/* angle between back and front arm */

   double pUnk;		/* percentage of unknown terrain */
} P3DRobotConfigGen;


typedef struct P3DNodeGen {
   double x,y,theta;	/* horizontal position relative to the robot */

   P3DRobotConfigGen conf;	/* robot configuration */
  /*  P3DRobotConfigGen *prev; */
  /* previous configuration */

#define P3D_UNDEF_COST	(-16384.0)	/* (should be negative) */

   double cost;		/* to reach this node from previous one */
   double remain;	/* to reach goal from this node */

   int number;		/* node number */
   int isLocalMin;	/* true if distance to goal is a local minimum */
/*    struct P3DArcGen *parent; */
/* arc of this node */
} P3DNodeGen;


typedef struct P3DArcGen {
   double r;		/* arc curvature */
   double cost;
   int n;		/* number of nodes actually used */
   int current;
   P3DNodeGen nodes[P3D_DEFAULT_MAX_NUMNODES];	/* array of configurations */
} P3DArcGen;

typedef struct P3DSolution {
    int depth; /* how many arcs there is in this solution */
    double ds;		/* nodes spacing */

#define P3D_SOLUTION_MAX_DEPTH 10
    /* arcs. The first arc is the nearest to the robot */
    P3DArcGen arcs[P3D_SOLUTION_MAX_DEPTH];
} P3DSolution;

/************************************************************/




/***********************************************************************/
/* Display params */

#define P3D_DEFAULT_DISPLAY_SERVER		"dala"


typedef struct P3D_DISPLAY_PARAMS {
  char	 serverName[P3D_MAX_STRLEN];

  double  arcLength;  /* Length of the arc to draw */

  int    numNodes;    /* Number of nodes used to draw the direction arc */
  float  scale;       /* scale for the mini Dalas displayed in GDHE */

} P3D_DISPLAY_PARAMS;


typedef enum P3D_GDHE_CONNECTION {
  P3D_GDHE_CONNECTED, P3D_GDHE_NOT_CONNECTED
} P3D_GDHE_CONNECTION;

typedef struct P3D_DISPLAY_STATE {
  P3D_GDHE_CONNECTION  gdheConnection;
  int   unused;
} P3D_DISPLAY_STATE;


/***********************************************************************/

/* Current Robot Position used for the planning */
typedef struct P3D_ROBOT_POS {
  double xRobot;
  double yRobot;
  double zRobot;

  double thetaRobot;
  double pitchRobot;
  double rollRobot;

} P3D_ROBOT_POS;



/***********************************************************************/

/* Current Robot Position used for the planning */
typedef struct P3D_DISPLAYCONFIG_PARAMS {
  int   firstNodeNb;
  int   lastNodeNb;
  int   interval;
  int   unused;

} P3D_DISPLAYCONFIG_PARAMS;


/***********************************************************************/
/* x,y,theta pos. for Place Robot Request */
typedef struct P3D_PLACEROBOT_PARAMS {
  double x;
  double y;
  double theta;

  int  gdheDisplay;  /* 1 if want to display the result in GDHE, 0 else */
  int  unused;

} P3D_PLACEROBOT_PARAMS;



/***********************************************************************/
/* Struct containing data from the config monitor */

typedef enum P3D_MONITOR_STATUS {
  P3D_MONITOR_OFF, P3D_MONITOR_ON
} P3D_MONITOR_STATUS;

typedef struct P3D_MONITOR_DATA {
  double distPitch;  /* predictedPitch - observedPitch */
  double distRoll;   /* predictedRoll - observedRoll */

  double probaPitch;  /* "shaped" distPitch */
  double probaRoll;  /* "shaped" distRoll  */

  double behavior;  /* Final "behavior pseudo-proba"  */

  P3D_MONITOR_STATUS  status; /* Status flag to know if Monitor activated or not */
  int  unused;

} P3D_MONITOR_DATA;



/***********************************************************************/
/* Struct containing params for the config monitor request */

typedef enum P3D_MONITOR_LOG_FLAG {
  P3D_MONITOR_LOG_OFF, P3D_MONITOR_LOG_ON
} P3D_MONITOR_LOG_FLAG;

#define P3D_MONITOR_LOG_DEFAULT_FILENAME	"/home/tpeynot/Images/p3dMonitorLog.data"

typedef struct P3D_MONITOR_PARAMS {
  P3D_MONITOR_LOG_FLAG logFlag;
  int  unused;
  char fileName[P3D_MAX_LENGTH_NAME];  /* Name of File where to save the logs */

} P3D_MONITOR_PARAMS;

/**********************************************************************/
/* Struct containing params for the dump arc request */

#define P3D_MAX_LEN		256
typedef enum P3D_DUMP_STATUS {
	P3D_DUMP_OFF, P3D_DUMP_ON
} P3D_DUMP_STATUS;

typedef struct P3D_DUMP_PARAMS {
	char baseName[P3D_MAX_LEN];
	int num;
	P3D_DUMP_STATUS status;
} P3D_DUMP_PARAMS;

#define P3D_DEFAULT_DUMP_NAME	"/tmp"
#define P3D_DEFAULT_DUMP_NUM	0


#endif /* P3DSTRUCT_H */
